@@ -19,21 +19,28 @@ list of parameters to monitor:
 """
 
 
-import sys
+import asyncio
+import json
 import logging
 import os
-import time
-import json
-from contextlib import suppress
-from typing import Dict, Union, Any, Optional, Sequence, Callable, Awaitable, TYPE_CHECKING
-from collections import defaultdict
-
-import asyncio
-from asyncio import CancelledError
-from threading import Thread, Event
-
 import socketserver
+import time
 import webbrowser
+from asyncio import CancelledError
+from collections import defaultdict
+from contextlib import suppress
+from threading import Event, Thread
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Awaitable,
+    Callable,
+    Dict,
+    Optional,
+    Sequence,
+    Union,
+)
+
 import websockets
 
 try:
@@ -48,14 +55,15 @@ if TYPE_CHECKING:
 
 from qcodes.instrument.parameter import Parameter
 
-
 WEBSOCKET_PORT = 5678
 SERVER_PORT = 3000
 
 log = logging.getLogger(__name__)
 
 
-def _get_metadata(*parameters: Parameter) -> Dict[str, Any]:
+def _get_metadata(
+    *parameters: Parameter, use_root_instrument: bool = True
+) -> Dict[str, Any]:
     """
     Return a dictionary that contains the parameter metadata grouped by the
     instrument it belongs to.
@@ -77,7 +85,10 @@ def _get_metadata(*parameters: Parameter) -> Dict[str, Any]:
         meta["unit"] = parameter.unit
 
         # find the base instrument that this parameter belongs to
-        baseinst = parameter.root_instrument
+        if use_root_instrument:
+            baseinst = parameter.root_instrument
+        else:
+            baseinst = parameter.instrument
         if baseinst is None:
             metas["Unbound Parameter"].append(meta)
         else:
@@ -93,8 +104,9 @@ def _get_metadata(*parameters: Parameter) -> Dict[str, Any]:
     return state
 
 
-def _handler(parameters: Sequence[Parameter], interval: float) \
-        -> Callable[["WebSocketServerProtocol", str], Awaitable[None]]:
+def _handler(
+    parameters: Sequence[Parameter], interval: float, use_root_instrument: bool = True
+) -> Callable[["WebSocketServerProtocol", str], Awaitable[None]]:
     """
     Return the websockets server handler.
     """
@@ -107,7 +119,9 @@ def _handler(parameters: Sequence[Parameter], interval: float) \
             try:
                 # Update the parameter values
                 try:
-                    meta = _get_metadata(*parameters)
+                    meta = _get_metadata(
+                        *parameters, use_root_instrument=use_root_instrument
+                    )
                 except ValueError:
                     log.exception("Error getting parameters")
                     break
@@ -130,13 +144,20 @@ class Monitor(Thread):
     """
     running = None
 
-    def __init__(self, *parameters: Parameter, interval: float = 1):
+    def __init__(
+        self,
+        *parameters: Parameter,
+        interval: float = 1,
+        use_root_instrument: bool = True,
+    ):
         """
         Monitor qcodes parameters.
 
         Args:
             *parameters: Parameters to monitor.
             interval: How often one wants to refresh the values.
+            use_root_instrument: Defines if parameters are grouped according to
+                                parameter.root_instrument or parameter.instrument
         """
         super().__init__()
 
@@ -151,7 +172,9 @@ class Monitor(Thread):
         self._parameters = parameters
         self.loop_is_closed = Event()
         self.server_is_started = Event()
-        self.handler = _handler(parameters, interval=interval)
+        self.handler = _handler(
+            parameters, interval=interval, use_root_instrument=use_root_instrument
+        )
 
         log.debug("Start monitoring thread")
         if Monitor.running:
@@ -264,18 +287,23 @@ class Monitor(Thread):
         webbrowser.open(f"http://localhost:{SERVER_PORT}")
 
 
-if __name__ == "__main__":
+def main() -> None:
     import http.server
+
     # If this file is run, create a simple webserver that serves a simple
     # website that can be used to view monitored parameters.
-    STATIC_DIR = os.path.join(os.path.dirname(__file__), 'dist')
-    os.chdir(STATIC_DIR)
+    static_dir = os.path.join(os.path.dirname(__file__), "dist")
+    os.chdir(static_dir)
     try:
         log.info("Starting HTTP Server at http://localhost:%i", SERVER_PORT)
         with socketserver.TCPServer(("", SERVER_PORT),
                                     http.server.SimpleHTTPRequestHandler) as httpd:
-            log.debug("serving directory %s", STATIC_DIR)
+            log.debug("serving directory %s", static_dir)
             webbrowser.open(f"http://localhost:{SERVER_PORT}")
             httpd.serve_forever()
     except KeyboardInterrupt:
         log.info("Shutting Down HTTP Server")
+
+
+if __name__ == "__main__":
+    main()
