@@ -3,6 +3,7 @@ import logging
 import re
 import time
 import warnings
+from contextlib import ExitStack
 from typing import List
 
 import numpy as np
@@ -59,8 +60,8 @@ def magnet_axes_instances():
     mag_z.close()
 
 
-@pytest.fixture(scope='function')
-def current_driver(magnet_axes_instances):
+@pytest.fixture(name="current_driver", scope="function")
+def _make_current_driver(magnet_axes_instances):
     """
     Instantiate AMI430_3D instrument with the three mock instruments
     representing current drivers for the x, y, and z directions.
@@ -74,8 +75,8 @@ def current_driver(magnet_axes_instances):
     driver.close()
 
 
-@pytest.fixture(scope='function')
-def ami430():
+@pytest.fixture(scope="function", name="ami430")
+def _make_ami430():
     mag = AMI430_VISA('ami430', address='GPIB::1::INSTR', visalib=visalib,
                       terminator='\n', port=1)
     yield mag
@@ -486,16 +487,176 @@ def test_ramp_rate_exception(current_driver):
     Test that an exception is raised if we try to set the ramp rate
     to a higher value than is allowed
     """
-    max_ramp_rate = AMI430_VISA._DEFAULT_CURRENT_RAMP_LIMIT
-    target_ramp_rate = max_ramp_rate + 0.01
     ix = current_driver._instrument_x
+    max_ramp_rate = ix.field_ramp_limit()
+    target_ramp_rate = max_ramp_rate + 0.01
 
-    with pytest.raises(Exception) as excinfo:
+    with pytest.raises(ValueError, match="is above the ramp rate limit of"):
         ix.ramp_rate(target_ramp_rate)
 
-        errmsg = f"must be between 0 and {max_ramp_rate} inclusive"
 
-        assert errmsg in excinfo.value.args[0]
+def test_simultaneous_ramp_mode_does_not_reset_individual_axis_ramp_rates_if_nonblocking_ramp(
+    current_driver, caplog, request
+):
+    ami3d = current_driver
+
+    ami3d.cartesian((0.0, 0.0, 0.0))
+
+    restore_parameters_stack = ExitStack()
+    request.addfinalizer(restore_parameters_stack.close)
+
+    restore_parameters_stack.callback(ami3d.cartesian, (0.0, 0.0, 0.0))
+
+    restore_parameters_stack.enter_context(
+        ami3d._instrument_x.ramp_rate.restore_at_exit()
+    )
+    restore_parameters_stack.enter_context(
+        ami3d._instrument_y.ramp_rate.restore_at_exit()
+    )
+    restore_parameters_stack.enter_context(
+        ami3d._instrument_z.ramp_rate.restore_at_exit()
+    )
+
+    restore_parameters_stack.enter_context(ami3d.ramp_mode.set_to("simultaneous"))
+
+    restore_parameters_stack.enter_context(ami3d.block_during_ramp.set_to(False))
+
+    # Set individual ramp rates to known values
+    ami3d._instrument_x.ramp_rate(0.09)
+    ami3d._instrument_y.ramp_rate(0.10)
+    ami3d._instrument_z.ramp_rate(0.11)
+
+    ami3d.vector_ramp_rate(0.05)
+
+    with caplog.at_level(logging.DEBUG, logger="qcodes.instrument.base"):
+
+        # Initiate the simultaneous ramp
+        ami3d.cartesian((0.5, 0.5, 0.5))
+
+        # Assert the individual axes ramp rates were changed and not reverted
+        # to the known values set earlier
+        assert ami3d._instrument_x.ramp_rate() != 0.09
+        assert ami3d._instrument_y.ramp_rate() != 0.10
+        assert ami3d._instrument_z.ramp_rate() != 0.11
+
+        # Assert the expected values of the ramp rates of the individual axes
+        # set by the simultaneous ramp based on the vector_ramp_rate and the
+        # setpoint magnetic field
+        expected_ramp_rate = pytest.approx(
+            0.5 / np.linalg.norm(ami3d.cartesian(), ord=2) * ami3d.vector_ramp_rate()
+        )
+        assert ami3d._instrument_x.ramp_rate() == expected_ramp_rate
+        assert ami3d._instrument_y.ramp_rate() == expected_ramp_rate
+        assert ami3d._instrument_z.ramp_rate() == expected_ramp_rate
+
+    messages = [record.message for record in caplog.records]
+
+    expected_log_fragment = "Simultaneous ramp: not blocking until ramp is finished"
+    messages_with_expected_fragment = tuple(
+        message for message in messages if expected_log_fragment in message
+    )
+    assert (
+        len(messages_with_expected_fragment) == 1
+    ), f"found: {messages_with_expected_fragment}"
+
+    unexpected_log_fragment = "Restoring individual axes ramp rates"
+    messages_with_unexpected_fragment = tuple(
+        message for message in messages if unexpected_log_fragment in message
+    )
+    assert (
+        len(messages_with_unexpected_fragment) == 0
+    ), f"found: {messages_with_unexpected_fragment}"
+
+    # However, calling ``wait_while_all_axes_ramping`` DOES restore the
+    # individual ramp rates
+
+    with caplog.at_level(logging.DEBUG, logger="qcodes.instrument.base"):
+        ami3d.wait_while_all_axes_ramping()
+
+    messages_2 = [record.message for record in caplog.records]
+
+    expected_log_fragment_2 = "Restoring individual axes ramp rates"
+    messages_with_expected_fragment_2 = tuple(
+        message for message in messages_2 if expected_log_fragment_2 in message
+    )
+    assert (
+        len(messages_with_expected_fragment_2) == 1
+    ), f"found: {messages_with_expected_fragment_2}"
+
+    # Assert calling ``wait_while_all_axes_ramping`` is possible
+
+    ami3d.wait_while_all_axes_ramping()
+
+
+def test_simultaneous_ramp_mode_resets_individual_axis_ramp_rates_if_blocking_ramp(
+    current_driver, caplog, request
+):
+    ami3d = current_driver
+
+    ami3d.cartesian((0.0, 0.0, 0.0))
+
+    restore_parameters_stack = ExitStack()
+    request.addfinalizer(restore_parameters_stack.close)
+
+    restore_parameters_stack.callback(ami3d.cartesian, (0.0, 0.0, 0.0))
+
+    restore_parameters_stack.enter_context(
+        ami3d._instrument_x.ramp_rate.restore_at_exit()
+    )
+    restore_parameters_stack.enter_context(
+        ami3d._instrument_y.ramp_rate.restore_at_exit()
+    )
+    restore_parameters_stack.enter_context(
+        ami3d._instrument_z.ramp_rate.restore_at_exit()
+    )
+
+    restore_parameters_stack.enter_context(ami3d.ramp_mode.set_to("simultaneous"))
+
+    restore_parameters_stack.enter_context(ami3d.block_during_ramp.set_to(True))
+
+    with caplog.at_level(logging.DEBUG, logger="qcodes.instrument.base"):
+
+        # Set individual ramp rates to known values
+        ami3d._instrument_x.ramp_rate(0.09)
+        ami3d._instrument_y.ramp_rate(0.10)
+        ami3d._instrument_z.ramp_rate(0.11)
+
+        ami3d.vector_ramp_rate(0.05)
+
+        # Initiate the simultaneous ramp
+        ami3d.cartesian((0.5, 0.5, 0.5))
+
+        # Assert the individual axes ramp rates were reverted
+        # to the known values set earlier
+        assert ami3d._instrument_x.ramp_rate() == 0.09
+        assert ami3d._instrument_y.ramp_rate() == 0.10
+        assert ami3d._instrument_z.ramp_rate() == 0.11
+
+    messages = [record.message for record in caplog.records]
+
+    expected_log_fragment = "Restoring individual axes ramp rates"
+    messages_with_expected_fragment = tuple(
+        message for message in messages if expected_log_fragment in message
+    )
+    assert (
+        len(messages_with_expected_fragment) == 1
+    ), f"found: {messages_with_expected_fragment}"
+
+    expected_log_fragment_2 = "Simultaneous ramp: blocking until ramp is finished"
+    messages_with_expected_fragment_2 = tuple(
+        message for message in messages if expected_log_fragment_2 in message
+    )
+    assert (
+        len(messages_with_expected_fragment_2) == 1
+    ), f"found: {messages_with_expected_fragment_2}"
+
+    unexpected_log_fragment = "Simultaneous ramp: not blocking until ramp is finished"
+    messages_with_unexpected_fragment = tuple(
+        message for message in messages if unexpected_log_fragment in message
+    )
+    assert (
+        len(messages_with_unexpected_fragment) == 0
+    ), f"found: {messages_with_unexpected_fragment}"
 
 
 def test_reducing_field_ramp_limit_reduces_a_higher_ramp_rate(ami430):
@@ -737,7 +898,8 @@ def test_current_and_field_params_interlink__change_field_ramp_limit(
 
 
 def test_current_and_field_params_interlink__change_coil_constant(
-        ami430, factor=3):
+    ami430, factor: float = 3
+):
     """
     Test that after changing ``change_coil_constant``, the values of the
     ``current_*`` parameters remain the same while the values of the
@@ -943,6 +1105,8 @@ def test_change_ramp_rate_units_parameter(ami430, new_value, unit_string,
     assert ami430.coil_constant.get_latest.get_timestamp() \
            > coil_constant_timestamp
 
+    ami430.ramp_rate_units("seconds")
+
 
 @pytest.mark.parametrize(('new_value', 'unit_string'),
                          (('tesla', 'T'), ('kilogauss', 'kG')),
@@ -979,3 +1143,12 @@ def test_change_field_units_parameter(ami430, new_value, unit_string):
     # Assert `coil_constant` value has been updated
     assert ami430.coil_constant.get_latest.get_timestamp() \
            > coil_constant_timestamp
+
+    ami430.field_units("tesla")
+
+def test_switch_heater_enabled(ami430):
+    assert ami430.switch_heater.enabled() is False
+    ami430.switch_heater.enabled(True)
+    assert ami430.switch_heater.enabled() is True
+    ami430.switch_heater.enabled(False)
+    assert ami430.switch_heater.enabled() is False
