@@ -2,7 +2,7 @@
 Provides validators for different types of values. Validator validates if the
 value belongs to the given type and is in the provided range.
 """
-import collections
+import collections.abc
 import math
 
 # rename on import since this file implements its own classes
@@ -17,6 +17,7 @@ from typing import Sequence as TSequence
 from typing import Tuple, TypeVar, Union, cast
 
 import numpy as np
+from typing_extensions import Literal
 
 from qcodes.utils.types import complex_types
 
@@ -589,20 +590,34 @@ class PermissiveMultiples(Validator[numbertypes]):
 
 class MultiType(Validator[Any]):
     """
-    Allow the union of several different validators.
-    For example, to allow numbers as well as "off":
-    MultiType(Numbers(), Enum("off"))
-    The resulting validator acts as a logical OR between the
-    different validators.
+    Allow the combination of several different validators.
+    By default, the resulting validator acts as a logical OR
+    between the different validators. Pass combiner='AND' to
+    require all validators to return True instead of atleast
+    one returning True.
+    Examples:
+        1. To allow numbers as well as "off":
+            MultiType(Numbers(), Enum("off"))
+            or:
+            MultiType(Numbers(), Enum("off"), combiner='OR')
+        2. To require values that are divisible by 0.001 while >=0.002 and <=50000.0
+            MultiType(PermissiveMultiples(divisor=1e-3),
+                      Numbers(min_value=2e-3, max_value=5e4),
+                      combiner='AND')
 
     Raises:
         TypeError: If no validators provided. Or if any of the provided
-            argument is not a valid validator.
+            argument is not a valid validator. Or if combiner is not in
+            ['OR', 'AND'].
     """
 
-    def __init__(self, *validators: Validator[Any]) -> None:
+    def __init__(
+        self, *validators: Validator[Any], combiner: Literal["OR", "AND"] = "OR"
+    ) -> None:
         if not validators:
-            raise TypeError('MultiType needs at least one Validator')
+            raise TypeError("MultiType needs at least one Validator")
+        if combiner not in ["OR", "AND"]:
+            raise TypeError("MultiType combiner argument must be one of ['OR', 'AND']")
 
         for v in validators:
             if not isinstance(v, Validator):
@@ -617,6 +632,7 @@ class MultiType(Validator[Any]):
                 self.is_numeric = True
 
         self._validators = tuple(validators)
+        self._combiner = combiner
         self._valid_values = tuple(vval for v in self._validators
                                    for vval in v._valid_values)
 
@@ -625,19 +641,78 @@ class MultiType(Validator[Any]):
         for v in self._validators:
             try:
                 v.validate(value, context)
-                return
+                if self._combiner == "OR":
+                    return
             except Exception as e:
                 # collect the args from all validators so you can see why
-                # each one failed
+                # each one that was tested failed
                 args = args + list(e.args)
+                if self._combiner == "AND":
+                    raise ValueError(*args)
 
-        raise ValueError(*args)
+        if self._combiner == "OR":
+            raise ValueError(*args)
 
     def __repr__(self) -> str:
         parts = (repr(v)[1:-1] for v in self._validators)
         return '<MultiType: {}>'.format(', '.join(parts))
 
 
+class MultiTypeOr(MultiType):
+    """
+    Allow the combination of several different validators.
+    The resulting validator acts as a logical OR between the
+    different validators.
+
+    Example:
+        To allow numbers as well as "off":
+            MultiTypeOr(Numbers(), Enum("off"))
+
+    Raises:
+        TypeError: If no validators provided. Or if any of the provided
+            argument is not a valid validator.
+    """
+
+    def __init__(
+        self,
+        *validators: Validator[Any],
+    ) -> None:
+        super().__init__(*validators, combiner="OR")
+
+    def __repr__(self) -> str:
+        parts = (repr(v)[1:-1] for v in self._validators)
+        return "<MultiTypeOr: {}>".format(", ".join(parts))
+
+
+class MultiTypeAnd(MultiType):
+    """
+    Allow the combination of several different validators.
+    The resulting validator acts as a logical AND between the
+    different validators.
+
+    Example:
+        To require values that are divisible by 0.001 while >=0.002 and <=50000.0
+            MultiType(PermissiveMultiples(divisor=1e-3),
+                      Numbers(min_value=2e-3, max_value=5e4),
+                      combiner='AND')
+
+    Raises:
+        TypeError: If no validators provided. Or if any of the provided
+            argument is not a valid validator.
+    """
+
+    def __init__(
+        self,
+        *validators: Validator[Any],
+    ) -> None:
+        super().__init__(*validators, combiner="AND")
+        self._valid_values = ()
+
+    def __repr__(self) -> str:
+        parts = (repr(v)[1:-1] for v in self._validators)
+        return "<MultiTypeAnd: {}>".format(", ".join(parts))
+
+
 class Arrays(Validator[np.ndarray]):
     """
     Validator for numerical numpy arrays of numeric types (int, float, complex).
@@ -733,7 +808,7 @@ class Arrays(Validator[np.ndarray]):
         if min_value is not None and max_value is not None:
             valuesok = max_value > min_value
             if not valuesok:
-                raise TypeError(f'max_value must be bigger than min_value')
+                raise TypeError("max_value must be bigger than min_value")
 
         if not isinstance(shape,
                           collections.abc.Sequence) and shape is not None:
